==> antd-pro-toolkit-0.6.0.tgz: package/es/Uploader/Image.js <==
import React from 'react';
import { Icon } from 'antd';

var Image = function Image(props) {
  var item = props.item,
      handlePreview = props.handlePreview,
      _props$isUploading = props.isUploading,
      isUploading = _props$isUploading === void 0 ? true : _props$isUploading,
      handleRemove = props.handleRemove;
  var imgType = ['png', 'jpeg', 'jpg', 'pdf'];
  var fileType = item.name.split('.').reverse()[0].toLowerCase();
  var canPrev = imgType.includes(fileType);
  return React.createElement(React.Fragment, null, React.createElement("div", {
    className: "ant-upload-list ant-upload-list-picture-card",
    onClick: function onClick() {
      return handlePreview(item);
    }
  }, React.createElement("div", {
    className: "ant-upload-list-item ant-upload-list-item-done",
    style: {
      width: 102,
      height: 102
    }
  }, React.createElement("div", {
    className: "ant-upload-list-item-info"
  }, React.createElement("span", {
    style: {
      height: '100%',
      textAlign: 'center'
    }
  }, canPrev ? React.createElement("a", {
    className: "ant-upload-list-item-thumbnail",
    style: {
      display: 'flex',
      justifyContent: 'center',
      alignItems: 'center'
    }
  }, fileType !== 'pdf' ? React.createElement("img", {
    src: item.path,
    alt: item.name || ''
  }) : React.createElement("iframe", {
    src: item.path,
    title: item.name
  })) : React.createElement(React.Fragment, null, React.createElement(Icon, {
    type: "picture",
    style: {
      fontSize: 26,
      lineHeight: 2,
      color: '#1890FF'
    }
  }), React.createElement("span", {
    className: "ant-upload-list-item-name"
  }, item.name)))), React.createElement("span", {
    className: "ant-upload-list-item-actions"
  }, React.createElement(Icon, {
    type: "eye",
    style: {
      cursor: 'pointer',
      color: '#fff',
      opacity: canPrev ? 1 : 0.4
    }
  }), isUploading ? React.createElement(Icon, {
    type: 'delete',
    style: {
      color: 'rgba(255, 255, 255, 0.85)',
      marginLeft: 10
    },
    onClick: function onClick(e) {
      e.stopPropagation();
      handleRemove(item);
    }
  }) : React.createElement("div", null)))));
};

export default Image;

==> antd-pro-toolkit-0.6.8.tgz: package/es/Uploader/Image.js <==
import React from 'react';
import { PictureOutlined, DeleteOutlined, EyeOutlined } from '@ant-design/icons';

var Image = function Image(props) {
  var item = props.item,
      handlePreview = props.handlePreview,
      _props$isUploading = props.isUploading,
      isUploading = _props$isUploading === void 0 ? true : _props$isUploading,
      handleRemove = props.handleRemove;
  var imgType = ['png', 'jpeg', 'jpg', 'pdf'];
  var fileType = item.name.split('.').reverse()[0].toLowerCase();
  var canPrev = imgType.includes(fileType);
  return React.createElement(React.Fragment, null, React.createElement("div", {
    className: "ant-upload-list ant-upload-list-picture-card",
    onClick: function onClick() {
      return handlePreview(item);
    }
  }, React.createElement("div", {
    className: "ant-upload-list-item ant-upload-list-item-done",
    style: {
      width: 102,
      height: 102
    }
  }, React.createElement("div", {
    className: "ant-upload-list-item-info"
  }, React.createElement("span", {
    style: {
      height: '100%',
      textAlign: 'center'
    }
  }, canPrev ? React.createElement("a", {
    className: "ant-upload-list-item-thumbnail",
    style: {
      display: 'flex',
      justifyContent: 'center',
      alignItems: 'center'
    }
  }, fileType !== 'pdf' ? React.createElement("img", {
    src: item.path,
    alt: item.name || ''
  }) : React.createElement("iframe", {
    src: item.path,
    title: item.name
  })) : React.createElement(React.Fragment, null, React.createElement(PictureOutlined, {
    style: {
      fontSize: 26,
      lineHeight: 2,
      color: '#1890FF'
    }
  }), React.createElement("span", {
    className: "ant-upload-list-item-name"
  }, item.name)))), React.createElement("span", {
    className: "ant-upload-list-item-actions"
  }, React.createElement(EyeOutlined, {
    style: {
      cursor: 'pointer',
      color: '#fff',
      opacity: canPrev ? 1 : 0.4
    }
  }), isUploading ? React.createElement(DeleteOutlined, {
    type: 'delete',
    style: {
      color: 'rgba(255, 255, 255, 0.85)',
      marginLeft: 10
    },
    onClick: function onClick(e) {
      e.stopPropagation();
      handleRemove(item);
    }
  }) : React.createElement("div", null)))));
};

export default Image;
